aboutsummaryrefslogtreecommitdiffstats
path: root/tools/firmware-utils
diff options
context:
space:
mode:
Diffstat (limited to 'tools/firmware-utils')
-rw-r--r--tools/firmware-utils/src/tplink-safeloader.c39
1 files changed, 38 insertions, 1 deletions
diff --git a/tools/firmware-utils/src/tplink-safeloader.c b/tools/firmware-utils/src/tplink-safeloader.c
index f8b8491326..c09ea347b2 100644
--- a/tools/firmware-utils/src/tplink-safeloader.c
+++ b/tools/firmware-utils/src/tplink-safeloader.c
@@ -881,7 +881,7 @@ static struct device_info boards[] = {
.last_sysupgrade_partition = "file-system",
},
/** Firmware layout for the C6v2 */
{
.id = "ARCHER-C6-V2",
.vendor = "",
@@ -916,6 +916,40 @@ static struct device_info boards[] = {
.last_sysupgrade_partition = "file-system",
},
+ /** Firmware layout for the Archer C6 v2 (US) and A6 v2 (US/TW) */
+ {
+ .id = "ARCHER-C6-V2-US",
+ .vendor = "",
+ .support_list =
+ "SupportList:\n"
+ "{product_name:Archer A6,product_ver:2.0.0,special_id:55530000}\n"
+ "{product_name:Archer A6,product_ver:2.0.0,special_id:54570000}\n"
+ "{product_name:Archer C6,product_ver:2.0.0,special_id:55530000}\n",
+ .support_trail = '\x00',
+ .soft_ver = "soft_ver:1.1.1\n",
+
+ .partitions = {
+ {"factory-boot", 0x00000, 0x20000},
+ {"default-mac", 0x20000, 0x00200},
+ {"pin", 0x20200, 0x00100},
+ {"product-info", 0x20300, 0x00200},
+ {"device-id", 0x20500, 0x0fb00},
+ {"fs-uboot", 0x30000, 0x20000},
+ {"firmware", 0x50000, 0xf89400},
+ {"soft-version", 0xfd9400, 0x00100},
+ {"extra-para", 0xfd9500, 0x00100},
+ {"support-list", 0xfd9600, 0x00200},
+ {"profile", 0xfd9800, 0x03000},
+ {"default-config", 0xfdc800, 0x03000},
+ {"partition-table", 0xfdf800, 0x00800},
+ {"user-config", 0xfe0000, 0x0c000},
+ {"certificate", 0xfec000, 0x04000},
+ {"radio", 0xff0000, 0x10000},
+ {NULL, 0, 0}
+ },
+ .first_sysupgrade_partition = "os-image",
+ .last_sysupgrade_partition = "file-system",
+ },
/** Firmware layout for the C60v1 */
{
@@ -2069,6 +2103,9 @@ static void build_image(const char *output,
} else if (strcasecmp(info->id, "ARCHER-C6-V2") == 0) {
const char mdat[11] = {0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00};
parts[5] = put_data("extra-para", mdat, 11);
+ } else if (strcasecmp(info->id, "ARCHER-C6-V2-US") == 0) {
+ const char mdat[11] = {0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 0x00, 0x01, 0x01, 0x00};
+ parts[5] = put_data("extra-para", mdat, 11);
}
size_t len;
@@ -881,7 +881,7 @@ static struct device_info boards[] = {
.last_sysupgrade_partition = "file-system",
},
- /** Firmware layout for the C6v2 */
+ /** Firmware layout for the Archer C6 v2 (EU/RU/JP) */
{
.id = "ARCHER-C6-V2",